import { query, execute } from '../database/db';

// Create a new task
export function createTask(sender: string, params: CreateTaskParams) {
  if (!params.description || params.description.trim().length < 3) {
    throw new Error('La descripción de la tarea debe tener al menos 3 caracteres');
  }

  if (params.dueDate && !isValidDate(params.dueDate)) {
    throw new Error('Fecha inválida. Use el formato YYYY-MM-DD');
  }

  const result = execute(
    'INSERT INTO tasks (description, created_by, assigned_to, due_date, completed) VALUES (?, ?, ?, ?, ?)',
    [params.description.trim(), sender, params.assignedTo || null, params.dueDate || null, false]
  );

  const task = getTaskById(result.lastInsertRowid);
  if (!task) {
    throw new Error('Error al crear la tarea');
  }
  return task;
}

function isValidDate(dateString: string): boolean {
  const date = new Date(dateString);
  return !isNaN(date.getTime());
}

// Assign a task
export function assignTask(taskId: number, assignedTo: string) {
  execute(
    'UPDATE tasks SET assigned_to = ? WHERE id = ?',
    [assignedTo, taskId]
  );
}

// Mark a task as completed
export function completeTask(taskId: number) {
  execute(
    'UPDATE tasks SET completed = TRUE WHERE id = ?',
    [taskId]
  );
}

// Get all tasks (for debugging or future use)
export function getTasks() {
  return query('SELECT * FROM tasks');
}

// Get pending tasks for a specific user
export function getPendingTasks(assignedTo: string) {
  return query(
    'SELECT * FROM tasks WHERE assigned_to = ? AND completed = FALSE',
    [assignedTo]
  );
}

// Get task by ID
export function getTaskById(taskId: number) {
  if (!Number.isInteger(taskId) || taskId <= 0) {
    throw new Error('ID de tarea inválido');
  }

  const tasks = query(
    'SELECT * FROM tasks WHERE id = ?',
    [taskId]
  );
  return tasks[0] || null;
}

// Validate task ID from string input
export function validateTaskId(taskIdStr: string): number {
  const taskId = parseInt(taskIdStr);
  if (isNaN(taskId) || taskId <= 0) {
    throw new Error('ID de tarea inválido. Debe ser un número positivo');
  }
  return taskId;
}
